<?php

namespace Drupal\lms\Entity;

use Drupal\Core\Entity\ContentEntityInterface;
use Drupal\Core\Entity\EntityChangedInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Provides an interface for defining Activity entities.
 */
interface ActivityInterface extends ContentEntityInterface, EntityChangedInterface, EntityOwnerInterface {

  /**
   * Gets the Activity type.
   *
   * @return string
   *   The Activity type.
   */
  public function getType();

  /**
   * Gets the current revision vid.
   *
   * @return string
   *   Vid.
   */
  public function getCurrentRevision();

  /**
   * Gets the Activity creation timestamp.
   *
   * @return int
   *   Creation timestamp of the Activity.
   */
  public function getCreatedTime();

  /**
   * Sets the Activity creation timestamp.
   *
   * @param int $timestamp
   *   The Activity creation timestamp.
   *
   * @return \Drupal\lms\Entity\OpignoActivityInterface
   *   The called Activity entity.
   */
  public function setCreatedTime($timestamp);

  /**
   * Returns the Activity published status indicator.
   *
   * Unpublished Activity are only visible to restricted users.
   *
   * @return bool
   *   TRUE if the Activity is published.
   */
  public function isPublished();

  /**
   * Sets the published status of a Activity.
   *
   * @param bool $published
   *   TRUE to set this Activity to published, FALSE to set it to unpublished.
   *
   * @return \Drupal\lms\Entity\OpignoActivityInterface
   *   The called Activity entity.
   */
  public function setPublished($published);

  /**
   * Gets a list of Answer revision IDs for a specific Answer.
   *
   * @return int[]
   *   Activity revision IDs (in ascending order).
   */
  public function revisionIds();

}
